OiRA

Help

1. Sagatavošanās
2. Iesaiste
3. Identifikācija + Novērtēšana
4. Rīcības plāns
   1. 1.1.1 Slips, trips and falls are not prevented.
   2. 1.1.2 Collisions, bumps, and jamming are not prevented.
   3. 1.1.4 Exposure to noise is neither prevented nor controlled.
   4. 1.1.6 Exposure to biological substances is neither prevented nor controlled
   5. Ω.1 The entrance floor is often wet
   6. Title of the first custom risk
   7. This is another custom risk added by the user
   - Uzmanību
5. Pārskats
6. Statuss 0%

##

Šis ir

A significant number of occupational accidents are related to moving around the client company’s premises, either inside or outside the buildings (e.g. static surveillance, rounds and surveillance patrols). These are...

#### Lasīt vairāk par šo risku.

Pellentesque habitant morbi tristique senectus et netus et malesuada fames ac turpis egestas. Vestibulum tortor quam, feugiat vitae, ultricies eget, tempor sit amet, ante. Donec eu libero sit amet quam egestas semper. Aenean ultricies mi vitae est. Mauris placerat eleifend leo.

- Lorem ipsum dolor sit amet, consectetuer adipiscing elit.
- Aliquam tincidunt mauris eu risus.
- Vestibulum auctor dapibus neque.

## Tipveida pasākums

Izvēlieties vienu tipveida pasākumu

Visual inspection of work areas. Pievienot Provide good equipment Pievienot Inform the private security guards Pievienot The private security guard reports correctly and immediately disfunction of electricity, gas and water systems. Pievienot

## Īstenotais pasākums: Visual inspection of work areas

#### Description

    Make sure a visual inspection of work areas is carried out in order to identify the potential hazards of falls and slips. Check that the anti-fall fittings and protective measures are present and in good condition."
        expertise: "Contrary to popular belief, Lorem Ipsum is not simply random text.

    Beware of the following possible hazards.

    - Slippery slopes
    - Falling pianos
    - Angry queens

    It has roots in a piece of classical Latin literature from 45 BC, making it over 2000 years old.

## Visual inspection of work areas.

Remove

#### Description

Make sure a visual inspection of work areas is carried out in order to identify the potential hazards of falls and slips. Check that the anti-fall fittings and protective measures are present and in good condition.

#### Expertise

Contrary to popular belief, Lorem Ipsum is not simply random text. It has roots in a piece of classical Latin literature from 45 BC, making it over 2000 years old.

Kura ir atbildīgā persona? Appoint someone in your company to be responsible for the implementation of this measure. This person will have the authority to take the steps described in the Plan and/or the responsibility to ensure that they are carried out. Budžets Although some measures do not cost any money, most do. The measures should therefore be budgeted for; include them in the annual budget round if necessary. Uzsākšanas datums Pabeigšanas datums

## Provide good equipment

Remove

#### Description

#### Expertise

Kura ir atbildīgā persona? Appoint someone in your company to be responsible for the implementation of this measure. This person will have the authority to take the steps described in the Plan and/or the responsibility to ensure that they are carried out. Budžets Although some measures do not cost any money, most do. The measures should therefore be budgeted for; include them in the annual budget round if necessary. Uzsākšanas datums Pabeigšanas datums

## Inform the private security guards

Remove

#### Description

#### Expertise

Kura ir atbildīgā persona? Appoint someone in your company to be responsible for the implementation of this measure. This person will have the authority to take the steps described in the Plan and/or the responsibility to ensure that they are carried out. Budžets Although some measures do not cost any money, most do. The measures should therefore be budgeted for; include them in the annual budget round if necessary. Uzsākšanas datums Pabeigšanas datums

## The private security guard reports correctly and immediately disfunction of electricity, gas and water systems.

Remove

#### Description

#### Expertise

Kura ir atbildīgā persona? Appoint someone in your company to be responsible for the implementation of this measure. This person will have the authority to take the steps described in the Plan and/or the responsibility to ensure that they are carried out. Budžets Although some measures do not cost any money, most do. The measures should therefore be budgeted for; include them in the annual budget round if necessary. Uzsākšanas datums Pabeigšanas datums

## Papildu pasākums #{1}

Noņemt

Apraksts Describe: 1) what is your general approach to eliminate or (if the risk is not avoidable) reduce the risk; 2) the specific action(s) required to implement this approach (to eliminate or to reduce the risk); 3) the level of expertise needed to implement the measure, for instance “common sense (no OSH knowledge required)”, “no specific OSH expertise, but minimum OSH knowledge or training and/or consultation of OSH guidance required”, or “OSH expert”. You can also describe here any other additional requirement (if any). Ekspertīze
Kura ir atbildīgā persona? Appoint someone in your company to be responsible for the implementation of this measure. This person will have the authority to take the steps described in the Plan and/or the responsibility to ensure that they are carried out. Budžets Although some measures do not cost any money, most do. The measures should therefore be budgeted for; include them in the annual budget round if necessary. Uzsākšanas datums Pabeigšanas datums

Scroll to top
Back

## action-plan.html

Help

Standard search Advanced search

- Splash and Shine Cleaners Last saved 19 days ago based on EU Cleaning More
- Commercial Guardinng, Leicester Last saved 2 months ago based on Private Security EU More
- Private Security, Grafton Street Last saved 2 months ago based on Private Security EU More
- Office operations in times of COVID-19 Last saved 4 months ago based on COVID-19 More